#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for mini_httpd module
#
# Copyright (c) 2003-2010 Andreas Pohl, apohl(at)ibp-consult(dot)com
# Copyright (c) 2011-2012 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2003-12-30 ap
# Last Update:  $Id: install.sh 30643 2012-04-29 10:35:59Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib
. /var/install/include/check-eisfair-version

# set variables
module_name='mini_httpd_sitecopy'

mini_httpd_path=/usr/local/htdocs

mecho --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

mecho "adding menu ..."
/var/install/bin/add-menu -menu "setup.services.mini_httpd.module.menu" \
    "setup.services.mini_httpd.module.${module_name}.menu" "Sitecopy - Smart FTP Uploader"

# menue entry does not exist - create it
mecho "adding ${module_name} module menu ..."

# delete menu entries (if already exist)
for CGINAME in ./sitecopy/sitecopy.cgi ./sitecopy/sitecopy.html
do
    /usr/local/bin/httpd-menu.sh rem "${CGINAME}"
done

# make menu entry (to update old installations)
if [ -f ${mini_httpd_path}/sitecopy/sitecopy.html ]
then
    /usr/local/bin/httpd-menu.sh add "./sitecopy/sitecopy.html" "Sitecopy" "Tools"
fi

# check directories and files
if [ ! -d ${mini_httpd_path}/sitecopy/status ]
then
    mecho "creating directories ..."

    mkdir -p ${mini_httpd_path}/sitecopy/status
fi

mecho "setting file/directory access rights ..."

chmod    700 ${mini_httpd_path}/sitecopy/status
chmod -R 550 ${mini_httpd_path}/sitecopy/*.cgi
chmod -R 550 ${mini_httpd_path}/sitecopy/*.sh

# install/update package configuration file
update=false
if install_config ${module_name}
then
    update=true
fi

# configuration
mecho "creating ${module_name} configuration ..."

if [ "${update}" = "true" ]
then
    # updated installation
    /var/install/config.d/${module_name}.sh
    if [ -f /etc/init.d/${module_name} ]
    then
        /etc/init.d/${module_name} restart
    fi
else
    # new installation
    /var/install/bin/edit -apply "${module_name}" "Edit ${module_name} services configuration"
fi

exit 0
