#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/bin/mini_httpd_sitecopy-update.sh - update or generate new configuration
#
# Copyright (c) 2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2011-04-18  jed
# Last Update:  $Id: mini_httpd_sitecopy-update.sh 28097 2011-04-21 12:15:17Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."

    if [ ${SITECOPY_N} -eq 0 ]
    then
        imax=1
    else
        imax=${SITECOPY_N}
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        if [ ! -z "`grep ^SITECOPY_${idx}_USERNAME ${source_conf}`" ]
        then
            eval alias_old='$SITECOPY_'${idx}'_USERNAME'
            eval alias_new="SITECOPY_${idx}_USER"

            mecho "- SITECOPY_${idx}_USERNAME -> SITECOPY_${idx}_USER"
            eval "${alias_new}=\"${alias_old}\""
            renamed=1
        fi

        if [ ! -z "`grep ^SITECOPY_${idx}_PASSWORD ${source_conf}`" ]
        then
            eval alias_old='$SITECOPY_'${idx}'_PASSWORD'
            eval alias_new="SITECOPY_${idx}_PASS"

            mecho "- MINI_HTTPD_USER_${idx}_PASSWORD -> MINI_HTTPD_USER_${idx}_PASS"
            eval "${alias_new}=\"${alias_old}\""
            renamed=1
        fi

        idx=`expr $idx + 1`
    done

    if [ ${renamed} -eq 1 ]
    then
        mecho -info "... read documentation for renamed parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."

  # if [ "$EXISCAN_CRYPT_SALT" = "" ]
  # then
  #     randsalt="`random_char``random_char`"
  #     mecho "-EXISCAN_CRYPT_SALT, '' -> '$randsalt'"
  #     EXISCAN_CRYPT_SALT="$randsalt"
  #     modified=1
  # fi

    if [ ${modified} -eq 1 ]
    then
        mecho -info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

    if [ "${START_SITECOPY}" = "no" -o ${SITECOPY_N} -eq 0 ]
    then
        imax=1
        def_answer='no'
    else
        imax=${SITECOPY_N}
        def_answer='yes'
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        eval atest='$SITECOPY_'${idx}'_ACTIVE'

        if [ "${atest}" = "" -a -z "`grep ^SITECOPY_${idx}_ACTIVE ${source_conf}`" ]
        then
            mecho "- SITECOPY_${idx}_ACTIVE='${def_answer}'"
            eval "SITECOPY_${idx}_ACTIVE='${def_answer}'"
            added=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ "${START_SITECOPY}" = "no" -o ${SITECOPY_LINK_N} -eq 0 ]
    then
        imax=1
        def_answer='no'
    else
        imax=${SITECOPY_LINK_N}
        def_answer='yes'
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        eval atest='$SITECOPY_LINK_'${idx}'_ACTIVE'

        if [ "${atest}" = "" -a -z "`grep ^SITECOPY_LINK_${idx}_ACTIVE ${source_conf}`" ]
        then
            mecho "- SITECOPY_LINK_${idx}_ACTIVE='${def_answer}'"
            eval "SITECOPY_LINK_${idx}_ACTIVE='${def_answer}'"
            added=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${added} -eq 1 ]
    then
        mecho -info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

  # for varname in "ANTISPAM_LOG_COUNT ANTISPAM_LOG_INTERVAL ANTISPAM_ACTIVATE_OSIRU_RBL"
  # do
  #     if [ ! -z "`grep \"^$varname\" $source_conf`" ]
  #     then
  #         mecho "- $varname"
  #         deleted=1
  #     fi
  # done

    if [ ${deleted} -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "${module_name}" "2011-04-18" "jed"
        #------------------------------------------------------------------------------
        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------

        printvar "START_SITECOPY"              "start sitecopy: yes or no"
        echo
        printvar "SITECOPY_N"                  "number of web projects"

        if [ ${SITECOPY_N} -eq 0 ]
        then
            imax=1
        else
            imax=${SITECOPY_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            printvar "SITECOPY_${idx}_ACTIVE"  "${idx}. activate web project name: yes, no"
            printvar "SITECOPY_${idx}_NAME"    "   web project name"
            printvar "SITECOPY_${idx}_SERVER"  "   name of ftp-server"
            printvar "SITECOPY_${idx}_URL"     "   url to check directory"
            printvar "SITECOPY_${idx}_USER"    "   username for ftp login"
            printvar "SITECOPY_${idx}_PASS"    "   password fir ftp login"
            printvar "SITECOPY_${idx}_LOCAL"   "   local directory path"
            printvar "SITECOPY_${idx}_REMOTE"  "   remote ftp path"

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printgroup "quick links"
        #------------------------------------------------------------------------------

        printvar "SITECOPY_LINK_N"                  "number of url targets"

        if [ ${SITECOPY_LINK_N} -eq 0 ]
        then
            imax=1
        else
            imax=${SITECOPY_LINK_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            printvar "SITECOPY_LINK_${idx}_ACTIVE"  "${idx}. url description"
            printvar "SITECOPY_LINK_${idx}_NAME"    "   url description"
            printvar "SITECOPY_LINK_1_TARGET"       "   url target"
            printvar "SITECOPY_LINK_1_HREF"         "   url reference link"

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}

    anykey
}

#==============================================================================
# main
#==============================================================================

#testroot=/soft/jedsitecopy
 testroot=''

module_name='mini_httpd_sitecopy'
configfile=${testroot}/etc/config.d/${module_name}
installfile=${testroot}/var/run/${module_name}.install
defaultfile=${testroot}/etc/default.d/${module_name}

# setting defaults
source_conf=${installfile}
generate_conf=${configfile}

goflag=0

case "$1"
in
    update)
        goflag=1
        ;;
    test)
        source_conf=${configfile}

        generate_conf=${testroot}/etc/config.d/${module_name}.test
        goflag=1
        ;;
    *)
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  ${module_name}-update.sh [update] - the file ${module_name}.import will be read, the configuration will"
        mecho "                                    be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        # previous configuration file exists
        mecho -info "previous configuration found ..."
        . ${source_conf}

        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        mecho -error "no configuration ${source_conf} found - exiting."
        anykey
    fi
fi

#==============================================================================
# end
#==============================================================================
