#!/bin/sh
#-------------------------------------------------------------------------------
# /var/install/config.d/mini_httpd_sitecopy.sh - configuration generator script
#
# Copyright (c) 2003-2010 Andreas Pohl, apohl(at)ibp-consult(dot)com
# Copyright (c) 2011-2012 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2003-12-30 ap
# Last Update:  $Id: mini_httpd_sitecopy.sh 30643 2012-04-29 10:35:59Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib

pgmname=`basename $0`

module_name="mini_httpd_sitecopy"

config_file=/etc/config.d/${module_name}
generate_rcfile=/usr/local/htdocs/sitecopy/.sitecopyrc

mini_httpd_version="v1.0.0-5"

### load configuration ###
. ${config_file}
chmod 600 ${config_file}

#----------------------------------------------------------------------------------------
# creating sitecopy configuration
#----------------------------------------------------------------------------------------
create_sitecopy_config ()
{
    mecho "creating sitecopy configuration file ..."

    /var/install/bin/backup-file --quiet ${generate_rcfile} backup

    {
        echo "#------------------------------------------------------------------"
        echo "# ${generate_rcfile} file generated by ${pgmname} ${mini_httpd_version}"
        echo "#"
        echo "# Do not edit this file, edit /etc/config.d/${module_name}"
        echo "# Creation Date: ${EISDATE} Time: ${EISTIME}"
        echo "#------------------------------------------------------------------"
    } > ${generate_rcfile}

    active_flag=0
    idx=1
    while [ ${idx} -le ${SITECOPY_N} ]
    do
        eval site_active='$SITECOPY_'${idx}'_ACTIVE'

        if [ "${site_active}" = "yes" ]
        then
            active_flag=1
            eval site_name='$SITECOPY_'${idx}'_NAME'
            eval site_server='$SITECOPY_'${idx}'_SERVER'
            eval site_url='$SITECOPY_'${idx}'_URL'
            eval site_username='$SITECOPY_'${idx}'_USER'
            eval site_password='$SITECOPY_'${idx}'_PASS'
            eval site_local='$SITECOPY_'${idx}'_LOCAL'
            eval site_remote='$SITECOPY_'${idx}'_REMOTE'

            mecho "- generate sitecopy settings for ${site_name} ..."

            {
                echo
                echo "site ${site_name}"
                echo "  server ${site_server}"
                echo "  url ${site_url}"
                echo "  username ${site_username}"
                echo "  password ${site_password}"
                echo "  local ${site_local}"
                echo "  remote ${site_remote}"
            } >> ${generate_rcfile}
        fi

        idx=`expr ${idx} + 1`
    done

    chmod 0600 ${generate_rcfile}

    if [ ${active_flag} -eq 0 ]
    then
        mecho --warn "- no active site configuration found!"
    fi
}

#========================================================================================
# main
#========================================================================================

case "$1" in
    *)
        # generate all configuration files
        mecho
        mecho "version: ${mini_httpd_version}"

        if [ "${START_SITECOPY}" = "yes" ]
        then
            create_sitecopy_config
        else
            mecho -warn "configuration has been disabled!"
        fi

        mecho "finished."
        ;;
esac

#========================================================================================
# End
#========================================================================================
exit 0
